==> gaiatest-0.8.tar.gz: gaiatest-0.8/gaiatest/tests/fmradio/test_fmradio_remove_from_favorite.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

from gaiatest import GaiaTestCase


class TestFMRadioRemoveFromFavorite(GaiaTestCase):

    _favorite_button_locator = ('id', 'bookmark-button')
    _favorite_list_locator = ('css selector', "div[class='fav-list-frequency']")
    _favorite_remove_locator = ('css selector', "div[class='fav-list-remove-button']")

    def setUp(self):
        GaiaTestCase.setUp(self)

        # launch the FM Radio app
        self.app = self.apps.launch('FM Radio')

    def test_remove_from_favorite(self):
        """ Remove a station from favorite list

        https://moztrap.mozilla.org/manage/case/1926/

        """
        # check the headphone is plugged-in or not
        self.assertTrue(self.data_layer.is_antenna_available, 'Antenna (headphones) not plugged in')

        # wait for the radio start-up
        self.wait_for_condition(lambda m: self.data_layer.is_fm_radio_enabled)

        # save the initial count of favorite stations
        initial_favorite_count = len(self.marionette.find_elements(*self._favorite_list_locator))

        # add the current frequency to favorite list
        self.wait_for_element_displayed(*self._favorite_button_locator)
        favorite_button = self.marionette.find_element(*self._favorite_button_locator)
        self.marionette.tap(favorite_button)
        self.wait_for_element_displayed(*self._favorite_remove_locator)

        # verify the change of favorite list after add
        after_add_favorite_count = len(self.marionette.find_elements(*self._favorite_list_locator))
        self.assertEqual(initial_favorite_count, after_add_favorite_count - 1)

        # remove the station from favorite list
        favorite_remove = self.marionette.find_element(*self._favorite_remove_locator)
        self.marionette.tap(favorite_remove)

        # verify the change of favorite after remove
        self.wait_for_element_not_displayed(*self._favorite_remove_locator)
        after_remove_favorite_count = len(self.marionette.find_elements(*self._favorite_list_locator))
        self.assertEqual(after_add_favorite_count - 1, after_remove_favorite_count)

==> gaiatest-0.13.tar.gz: gaiatest-0.13/gaiatest/tests/fmradio/test_fmradio_remove_from_favorite.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

from gaiatest import GaiaTestCase
from gaiatest.apps.fmradio.app import FmRadio


class TestFMRadioRemoveFromFavorite(GaiaTestCase):

    def setUp(self):
        GaiaTestCase.setUp(self)

        # launch the FM Radio app
        self.fm_radio = FmRadio(self.marionette)
        self.fm_radio.launch()

    def test_remove_from_favorite(self):
        """ Remove a station from favorite list

        https://moztrap.mozilla.org/manage/case/1926/

        """
        # check the headphone is plugged-in or not
        self.assertTrue(self.data_layer.is_antenna_available, 'Antenna (headphones) not plugged in')

        # wait for the radio start-up
        self.wait_for_condition(lambda m: self.data_layer.is_fm_radio_enabled)

        # add the current frequency to favorite list
        self.fm_radio.tap_add_favorite()

        # verify the change of favorite list after add
        self.assertEqual(1, len(self.fm_radio.favorite_channels))

        # remove the station from favorite list
        self.fm_radio.favorite_channels[0].remove()
        # TODO: The remove method should wait for the favourite to be removed. bug 864296
        self.fm_radio.wait_for_favorite_list_not_displayed()

        # verify the change of favorite after remove
        self.assertEqual(0, len(self.fm_radio.favorite_channels))

    def tearDown(self):
        # remove the station from favorite list
        for favorite_channel in self.fm_radio.favorite_channels:
            favorite_channel.remove()

        GaiaTestCase.tearDown(self)
